voxelops.schemas package
========================

Typed dataclass schemas for procedure inputs, expected outputs, and
default configurations. Each procedure defines three dataclasses:
``Inputs``, ``Outputs``, and ``Defaults``.

HeudiConv
---------

.. automodule:: voxelops.schemas.heudiconv
   :members:
   :undoc-members:
   :show-inheritance:

QSIPrep
-------

.. automodule:: voxelops.schemas.qsiprep
   :members:
   :undoc-members:
   :show-inheritance:

QSIRecon
--------

.. automodule:: voxelops.schemas.qsirecon
   :members:
   :undoc-members:
   :show-inheritance:

QSIParc
-------

.. automodule:: voxelops.schemas.qsiparc
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: voxelops.schemas
   :members:
   :undoc-members:
   :show-inheritance:
